# eric7.Plugins.VcsPlugins.vcsMercurial.HgArchiveDialog

Module implementing a dialog to enter the archive data.

### Global Attributes

None

### Classes

HgArchiveDialog | Class implementing a dialog to enter the archive data.

### Functions

None

## HgArchiveDialog

Class implementing a dialog to enter the archive data.

### Derived from

QDialog, Ui_HgArchiveDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgArchiveDialog | Constructor
getData | Public method to retrieve the data.
on_archivePicker_textChanged | Private slot to handle changes of the archive name.
on_typeComboBox_activated | Private slot to react on changes of the selected archive type.

### Static Methods

None

#### HgArchiveDialog (Constructor)

HgArchiveDialog(vcs, parent=None)

Constructor

vcs (Hg)
  reference to the Mercurial object (Hg)
parent (QWidget)
  reference to the parent widget

#### HgArchiveDialog.getData

getData()

Public method to retrieve the data.

Return:
  tuple giving the archive name, the archive type, the directory prefix and a flag indicating to recurse into subrepositories

Return Type:
  tuple of (str, str, str, bool)

#### HgArchiveDialog.on_archivePicker_textChanged

on_archivePicker_textChanged(archive)

Private slot to handle changes of the archive name.

archive (str)
  name of the archive

#### HgArchiveDialog.on_typeComboBox_activated

on_typeComboBox_activated(index)

Private slot to react on changes of the selected archive type.

index (int)
  index of the selected type

Up